==> commons-1.0.1-rc3-sources.jar: com/flybits/commons/library/api/idps/JwtIDP.kt <==
package com.flybits.commons.library.api.idps

import android.content.Context
import android.os.Parcel
import android.os.Parcelable
import com.flybits.commons.library.models.User
import org.json.JSONObject
import java.util.*

private const val USERAGENT_ENDPOINT = "/sso/devices/xuseragent"
private const val ME_ENDPOINT = "/me"

private const val JWT_PROVIDER = "jwt"

/**
 * The [JwtIDP] class is responsible for accepting the token and authenticating the User.
 *
 */
class JwtIDP : IDP {

    private val jwt: String

    /**
     * Constructor used for JWTIDP.
     *
     * @param jwt The Token is a security token that contains Claims about the Authentication
     *                  of an End-User by an Authorization Server.
     */
    constructor(jwt: String) : super(JWT_PROVIDER) {
        this.jwt = jwt
    }

    /**
     * Constructor used to read the data
     *
     * @param parcel The parcel is for reading the attribute idToken
     *
     */
    constructor(parcel: Parcel) : super(parcel) {
        jwt = parcel.readString() ?: ""
    }

    override fun getRequestType(): HttpMethod {
        return HttpMethod.POST
    }

    override fun getHeaders(): HashMap<String, String> {
        val headers = HashMap<String, String>()
        headers["X-Authorization"] = jwt
        return headers
    }

    fun getUserInfoEndPoint() = ME_ENDPOINT

    override fun describeContents() = 0

    override fun onAuthenticated(context: Context, user: User) {}

    override val authenticationEndPoint: String
        get() = USERAGENT_ENDPOINT

    override fun getBody(): JSONObject? = null

    override fun writeToParcel(parcel: Parcel, flags: Int) {
        super.writeToParcel(parcel, flags)
        parcel.writeString(jwt)
    }

    companion object CREATOR : Parcelable.Creator<JwtIDP> {
        override fun createFromParcel(parcel: Parcel): JwtIDP {
            return JwtIDP(parcel)
        }

        override fun newArray(size: Int): Array<JwtIDP?> {
            return arrayOfNulls(size)
        }
    }
}

==> commons-2.1.3-sources.jar: com/flybits/commons/library/api/idps/JwtIDP.kt <==
package com.flybits.commons.library.api.idps

import android.content.Context
import android.os.Parcel
import android.os.Parcelable
import com.flybits.commons.library.SharedElementsFactory
import com.flybits.commons.library.api.results.callbacks.BasicResultCallback
import com.flybits.commons.library.exceptions.FlybitsException
import com.flybits.commons.library.models.Device
import com.flybits.commons.library.models.User
import java.util.*


private const val ME_ENDPOINT = "/me"
private const val JWT_PROVIDER = "jwt"


/**
 * The [JwtIDP] class is responsible for accepting the token and authenticating the User.
 *
 */
class JwtIDP : IDP {

    private val jwt: String

    /**
     * Constructor used for JWTIDP.
     *
     * @param jwt The Token is a security token that contains Claims about the Authentication
     *                  of an End-User by an Authorization Server.
     */
    constructor(jwt: String) : super(JWT_PROVIDER) {
        this.jwt = jwt
    }


    /**
     * Constructor used to read the data
     *
     * @param parcel The parcel is for reading the attribute idToken
     *
     */
    constructor(parcel: Parcel) : super(parcel) {
        jwt = parcel.readString() ?: ""
    }

    override fun getRequestType(): HttpMethod {
        return HttpMethod.GET
    }

    override fun getHeaders(): HashMap<String, String> {
        val headers = HashMap<String, String>()
        headers["X-Authorization"] = jwt
        return headers
    }

    override fun getAuthenticationEndPoint() = ME_ENDPOINT

    override fun describeContents() = 0

    override fun getBody() = null

    override fun onAuthenticated(context: Context, user: User) {
        val sharedElements = SharedElementsFactory.get(context)
        sharedElements.setJWTToken(jwt)

        // Call to set User Agent to Flybits
        val device = Device()
        device.setUserAgent(context, object : BasicResultCallback {
            override fun onSuccess() {
                sharedElements.setUserAgent(true)
            }

            override fun onException(exception: FlybitsException) {
                sharedElements.setUserAgent(false)
            }
        })
    }

    override fun writeToParcel(parcel: Parcel, flags: Int) {
        super.writeToParcel(parcel, flags)
        parcel.writeString(jwt)
    }

    companion object CREATOR : Parcelable.Creator<JwtIDP> {
        override fun createFromParcel(parcel: Parcel): JwtIDP {
            return JwtIDP(parcel)
        }

        override fun newArray(size: Int): Array<JwtIDP?> {
            return arrayOfNulls(size)
        }
    }
}
